@@ -14,8 +14,11 @@ class FilesResource(Resource, metaclass=ABCMeta):
     async def open(self, path: Any, *args, **kwargs) -> Any:
         raise NotImplementedError
 
+    async def remove(self, path: Any, *args, **kwargs):
+        raise NotImplementedError
+
     async def list(self, path: Any, *args, **kwargs):
         raise NotImplementedError
 
-    def exists(self, path: Any) -> bool:
+    async def exists(self, path: Any) -> bool:
         raise NotImplementedError
