@@ -1,13 +1,18 @@
-import os
+import shutil
 from enum import Enum
 from pathlib import Path
 from typing import Type, TypeVar, Generic, Any, Generator
+from aiofiles import os
+from aiofiles.os import wrap
 from aiofiles.threadpool import open
 from aiofiles.base import AiofilesContextManager
 
 from web_foundation.kernel.channel import IChannel
 from web_foundation.resources.files.interface import FilesResource
 
+rmtree = wrap(shutil.rmtree)
+
+
 class OsFilesResource(FilesResource):
 
     def __init__(self, root, *args, **kwargs):
@@ -23,6 +28,12 @@ class OsFilesResource(FilesResource):
     async def open(self, path: Path, *args, **kwargs) -> AiofilesContextManager:
         return open(self.root.joinpath(path), *args, **kwargs)
 
+    async def remove(self, path: Path, *args, **kwargs):
+        if path.is_dir():
+            await rmtree(path, *args, **kwargs)
+        else:
+            await os.remove(path, *args, **kwargs)
+
     async def list(self, path: Path, *args, **kwargs) -> Generator[Path, None, None]:
         target = self.root.joinpath(path)
         return target.iterdir()
